function theta = get_theta(pos_matrix_geo, spin_axis)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function calculates the angle between the magnetic field and the
% projection of the magnetic field onto the spin plane. 
%
% Inputs:
% pos_matrix_geo - positional data (GEI and GEO coordinates)
% spin_axis - spin axis data
%
% Outputs:
% theta - angle between the magnetic field and the projection of the
% magnetic field onto the spin plane (degrees)
%
% Expected format of input matrices
% pos_matrix_geo(:,1)       = unix time
% pos_matrix_geo(:,2:4)     = pos x,y,z (gei)
% pos_matrix_geo(:,5:7)     = vel x,y,z (gei)
% pos_matrix_geo(:,8:10)    = pos x,y,z (geo)
% pos_matrix_geo(:,11:13)   = vel x,y,z (geo)
% pos_matrix_geo(:,14:16)   = altitude, latitude, longitude
% pos_matrix_geo(:,17:19)   = b-model x,y,z (gei)
% pos_matrix_geo(:,20:22)   = b-model x,y,z (geo)
% pos_matrix_geo(:,23)      = ilat
% pos_matrix_geo(:,24)      = mlt
%
% spin_axis(:,1)   = unix time
% spin_axis(:,2:4) = spin axis (GEI)
% spin_axis(:,5:7) = spin axis (GEO)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


bmod_geo = pos_matrix_geo(:,20:22);
%pos_matrix_geo(:,1:3) = B Model x,y,z (GEO)

sa_matrix = spin_axis(:,5:7);
%sa_matrix(:,1:3) = spin axis (GEO)

%normalize the bmodel
bmod_geo_norm = normr(bmod_geo);

%dot product
theta_tmp = bsxfun(@times,bmod_geo_norm,sa_matrix);
theta_tmp = theta_tmp(:,1) + theta_tmp(:,2) + theta_tmp(:,3);

theta = 90 - acosd(theta_tmp);

end
