function orbitNum = search_orbit( fastdata, time, dtime)
%
%       Written By: Steven Chen
%                   Feb. 3, 2011
%                   googly.bear@gmail.com
%
%       Uses a binary search algorithm to locate the orbit of the suggested
%       time input.
%   
%INPUT:
%       fastdata = directory where the Fast satellite data is located
%       time = the time of when you want to search for
%       dtime = the time that you do not want to exceed
%
%OUTPUT: 
%       orbitNum = the orbit number with which the time falls within
%
%COMMENTS:
%       This function should not be used for general purposes. This is a
%       helper function that assists process_orbit
%



        dir_listing = dir(fastdata);    %   Gets a listing of the directories
        
        startdir = dir_listing(3).name; %   Gets the starting directory skipping '.' and '..'
        enddir = dir_listing(end).name; %   Gets the ending directory
        
        cprintf('blue','Found orbit directories from %s to %s.\n',startdir,enddir);
        
        %   Now limit the amount of orbits to search through so that lower
        %   process does not have to go through so many. Uses a binary
        %   search algorithm with ascending correction if the folder does 
        %   not contain any data.
        
        last = length(dir_listing); %  Number of directories in folder
        
        first = 3;  %   Set to three to skip the folders '.' and '..'
        flag = 0;   %   Normally flag set 0 for initialization
        
        
        orbitIndex = [];    %   Initialize variable so it doesn't bomb out
        
        %   Start of the binary search algorithm. In essence this will find
        %   the orbit that will contain the matching start time inputted in
        %   the process_orbit function during 'statistics' mode
        
        while( first < last )
            %   Only calculate mid if the flag is set
            if(flag ==0)
            mid = floor((first + last) / 2);
            end
            
            
            %   Finds the current directory that is needed to compare
            %   against the time and make sure that the directory CDFs
            %   exist
            
            orbitname = dir_listing(mid).name;
            orbitnum = orbitname(length(orbitname)-4:end);
            iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
            eesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
            orb_path = strcat(fastdata, orbitname, '\', orbitname, '_orb.cdf');
            ef_path = strcat(fastdata, orbitname, '\', orbitname, '_ef.cdf');
            sa_path = strcat(fastdata, orbitname, '\', orbitname, '_sa.cdf');
            db_path = strcat(fastdata, orbitname, '\', orbitname, '_mag.cdf');
            ies_path = strcat(fastdata, orbitname, '\', iesorbitname);
            ees_path = strcat(fastdata, orbitname, '\', eesorbitname);
            
            %   Only execute if the directory exists
            if(exist(orb_path, 'file') == 2 ...
                        && exist(ef_path, 'file') == 2 ...
                        && exist(db_path, 'file') == 2 ...
                        && exist(sa_path, 'file') == 2 ...
                        && exist(ies_path, 'file') == 2 ...
                        && exist(ees_path, 'file') == 2)
                %   Extract just the time vector to compare the input time
                timerange = cdfread(orb_path, 'Variable', 'TIME');
                
                %   Check if the input time is within the range of the
                %   start and end time of the orbit.
                if ( time >= timerange{1} && time <= timerange{end})
                    %   If found then break out of loop and return the
                    %   value.
                    orbitIndex = mid;
                    break;
                end
                
                if ( time > timerange{end})
                    %   Time must be above the midpoint index
                    first = mid +1;
                else
                    %   Time must be below the midpoint index
                    last = mid-1;
                end
                %   Reset the flag so it can correctly calculate the new
                %   midpoint value.
                flag = 0;
            else
                %   Else change the flag because the orbit directory was
                %   not found, so to circumvent this increment the midpoint
                %   index by 1 to search the next directory. There may
                %   possibly be a better way to resolve this issue.
                flag = 1;
                mid = mid + 1;
            end
        end
        
        %   Check to see if the orbitIndex is empty, which means that the
        %   function did not find the orbit in the directory.
        %   Currently only scrolls up orbits until it finds a valid orbit,
        %   if not returns empty set.
        if(isempty(orbitIndex))
            orbitIndex = mid;
            while( orbitIndex <= length(dir_listing))
                
                orbitname = dir_listing(mid).name;
                orbitnum = orbitname(length(orbitname)-4:end);
                iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                eesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                orb_path = strcat(fastdata, orbitname, '\', orbitname, '_orb.cdf');
                ef_path = strcat(fastdata, orbitname, '\', orbitname, '_ef.cdf');
                sa_path = strcat(fastdata, orbitname, '\', orbitname, '_sa.cdf');
                db_path = strcat(fastdata, orbitname, '\', orbitname, '_mag.cdf');
                ies_path = strcat(fastdata, orbitname, '\', iesorbitname);
                ees_path = strcat(fastdata, orbitname, '\', eesorbitname);
                
                if(exist(orb_path, 'file') == 2 ...
                        && exist(ef_path, 'file') == 2 ...
                        && exist(db_path, 'file') == 2 ...
                        && exist(sa_path, 'file') == 2 ...
                        && exist(ies_path, 'file') == 2 ...
                        && exist(ees_path, 'file') == 2)
                    break;
                end
                orbitIndex = orbitIndex + 1;
            end
            
            timerange = cdfread(orb_path, 'Variable', 'TIME');
            
            if(timerange{end} >= dtime)
                cprintf('red','Orbit times not found within directory...\n');
                orbitNum = [];
                return
            end
            
            cprintf('green','Directory located was at directory index %d rather than %d and the\n orbit name is %s\n', orbitIndex,mid-1, dir_listing(orbitIndex).name);
            %   Returns the double value of the orbit to continue
            %   processing
            orbitNum = str2double(dir_listing(orbitIndex).name(length(dir_listing(orbitIndex).name )- 4:end));
        else
            %   Else the orbit was found. Prints the orbit index for debug
            %   purposes and prints the orbitname
            cprintf('green','Directory located was at directory index %d and the\n orbit name is %s\n', orbitIndex, dir_listing(orbitIndex).name);
            %   Returns the double value of the orbit to continue
            %   processing
            orbitNum = str2double(dir_listing(orbitIndex).name(length(dir_listing(orbitIndex).name )- 4:end));
            
        end
            
end

