function orbit_list = sequential_orbit( fastdata, limited_unix_time_matrix, orbit_start, orbit_end )
%
%       Written By: Steven Chen
%                   Feb. 22, 2011
%                   googly.bear@gmail.com
%INPUT:
%       fastdata = directory where the Fast satellite data is located
%       limited_unix_time_matrix = a shortened list of unix times that fall
%       within the kp_index
%       orbit_start = the starting orbit number
%       orbit_end = the ending orbit number
%
%OUTPUT: 
%       orbit_list = a list of all viable orbits
%
%COMMENTS:
%       This function should not be used for general purposes. This is a
%       helper function that assists process_orbit
%



        dir_listing = dir(fastdata);    %   Gets a listing of the directories
        
        startdir = dir_listing(3).name; %   Gets the starting directory skipping '.' and '..'
        enddir = dir_listing(end).name; %   Gets the ending directory
        
        cprintf('blue','Found orbit directories from %s to %s.\n',startdir,enddir);
        
        %   Now limit the amount of orbits to search through so that lower
        %   process does not have to go through so many.
        
        first = orbit_start;
        last = orbit_end;
       j = 0;
        orbit_list = zeros(length(limited_unix_time_matrix),1);
        for i = first:last
            
            %   Finds the current directory that is needed to compare
            %   against the time and make sure that the directory CDFs
            %   exist
            j = j+1;
        orbitname = dir_listing(2 + i).name; % Skips the initial 2 folders to start at the initial count
        orb_path = strcat(fastdata,  orbitname, '\', orbitname, '_orb.cdf');
        ef_path = strcat(fastdata, orbitname, '\', orbitname, '_ef.cdf');
        db_path = strcat(fastdata, orbitname, '\', orbitname, '_mag.cdf');
        sa_path = strcat(fastdata, orbitname, '\', orbitname, '_sa.cdf');
        iesorbitname = strcat('fa_k0_ies_0',int2str(i),'_v04.cdf');
        eesorbitname = strcat('fa_k0_ees_0',int2str(i),'_v04.cdf');
        ies_path = strcat(fastdata, orbitname, '\', iesorbitname);
        ees_path = strcat(fastdata, orbitname, '\', eesorbitname);
            
            %   Only execute if the directory exists
            if(exist(orb_path, 'file') == 2 ...
                        && exist(ef_path, 'file') == 2 ...
                        && exist(db_path, 'file') == 2 ...
                        && exist(sa_path, 'file') == 2 ...
                        && exist(ies_path, 'file') == 2 ...
                        && exist(ees_path, 'file') == 2)
                %   Extract just the time vector to compare the input time
                timerange = cdfread(ef_path, 'CombineRecords', true, 'Variable', 'TIME');
                
                %   Check if the input time is within the range of the
                %   start and end time of the orbit.
                    
                    
                        
                    index2 =(limited_unix_time_matrix <= timerange(end) ...
                        & limited_unix_time_matrix + 10800 >= timerange(end)); 
                    
                    if(any(orbit_list(index2) ==0))
                         orbit_list(index2) = i;
                    end

                    index = (limited_unix_time_matrix <= timerange(1) ...
                        & limited_unix_time_matrix + 10800 >= timerange(1));
                    
                    if(any(orbit_list(index) ==0))
                         orbit_list(index) = i;
                    end
            end
            
        end

end

